Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(508)

Unified Diff: chrome/browser/chromeos/file_system_provider/operations/get_metadata.h

Issue 258783006: [fsp] Add the getMetadata operation. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed a lot. Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/file_system_provider/operations/get_metadata.h
diff --git a/chrome/browser/chromeos/file_system_provider/operations/unmount.h b/chrome/browser/chromeos/file_system_provider/operations/get_metadata.h
similarity index 59%
copy from chrome/browser/chromeos/file_system_provider/operations/unmount.h
copy to chrome/browser/chromeos/file_system_provider/operations/get_metadata.h
index 2db0e90d538e6502401a83ddb98f0602795d6e67..804bc3e901274d9547ae90594dfaa742c28b4a5e 100644
--- a/chrome/browser/chromeos/file_system_provider/operations/unmount.h
+++ b/chrome/browser/chromeos/file_system_provider/operations/get_metadata.h
@@ -2,16 +2,18 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_OPERATIONS_UNMOUNT_H_
-#define CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_OPERATIONS_UNMOUNT_H_
+#ifndef CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_OPERATIONS_GET_METADATA_H_
+#define CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_OPERATIONS_GET_METADATA_H_
#include "base/files/file.h"
#include "base/memory/scoped_ptr.h"
#include "chrome/browser/chromeos/file_system_provider/operations/operation.h"
+#include "chrome/browser/chromeos/file_system_provider/provided_file_system_info.h"
+#include "chrome/browser/chromeos/file_system_provider/request_value.h"
#include "webkit/browser/fileapi/async_file_util.h"
namespace base {
-class DictionaryValue;
+class FilePath;
} // namespace base
namespace extensions {
@@ -20,19 +22,17 @@ class EventRouter;
namespace chromeos {
namespace file_system_provider {
-
-class ProvidedFileSystemInfo;
-
namespace operations {
-// Bridge between fileBrowserPrivate's unmount operation and providing
-// extension's unmount request. Created per request.
-class Unmount : public Operation {
+// Bridge between fileapi read directory operation and providing extension's
+// read directory request. Created per request.
+class GetMetadata : public Operation {
public:
- Unmount(extensions::EventRouter* event_router,
- const ProvidedFileSystemInfo& file_system_info,
- const fileapi::AsyncFileUtil::StatusCallback& callback);
- virtual ~Unmount();
+ GetMetadata(extensions::EventRouter* event_router,
+ const ProvidedFileSystemInfo& file_system_info,
+ const base::FilePath& directory_path,
+ const fileapi::AsyncFileUtil::GetFileInfoCallback& callback);
+ virtual ~GetMetadata();
// Operation overrides.
virtual bool Execute(int request_id) OVERRIDE;
@@ -42,13 +42,14 @@ class Unmount : public Operation {
virtual void OnError(int request_id, base::File::Error error) OVERRIDE;
private:
- const fileapi::AsyncFileUtil::StatusCallback callback_;
+ base::FilePath directory_path_;
+ const fileapi::AsyncFileUtil::GetFileInfoCallback callback_;
- DISALLOW_COPY_AND_ASSIGN(Unmount);
+ DISALLOW_COPY_AND_ASSIGN(GetMetadata);
};
} // namespace operations
} // namespace file_system_provider
} // namespace chromeos
-#endif // CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_OPERATIONS_UNMOUNT_H_
+#endif // CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_OPERATIONS_GET_METADATA_H_

Powered by Google App Engine
This is Rietveld 408576698